@@ -1,5 +1,6 @@
 import base64
 from hashlib import sha1
+from cache_gs.utils.types import default_to
 
 
 def int_to_base64(i: int) -> str:
@@ -14,7 +15,6 @@ def base64_to_int(b: str) -> int:
 
 def section_key_hash(section: str, key: str) -> str:
     """ Returns a sha1 hash (40 chars) from section_key value """
-    sk = ("_" if not isinstance(section, str) or not section else section)+"." +\
-        ("_" if not isinstance(key, str) or not key else key)
+    sk = ".".join([default_to(section), default_to(key)])
     hash = sha1(sk.encode('utf-8')).hexdigest()
     return hash
