@@ -1,4 +1,3 @@
-import datetime
 import os
 import unittest
 from unittest.mock import Mock, patch
@@ -7,6 +6,10 @@ from cache_gs.cache_classes.cache_data_file import CacheData, CacheDataFile
 from tests.test_tools import raise_test_exception
 
 
+def force_exception(*args, **kwargs):
+    raise_test_exception()
+
+
 class TestCacheDataFile(unittest.TestCase):
 
     def setUp(self):
@@ -24,21 +27,12 @@ class TestCacheDataFile(unittest.TestCase):
         cdf2 = CacheDataFile(self.file_name)
         self.assertEqual(cdf.data, cdf2.data)
 
-        cd2 = CacheData("test_section", "test_key",
-                        "test_value_", 0, datetime.datetime.now())
-        self.assertNotEqual(cd, cd2)
-
-        self.assertNotEqual(cd, None)
-
-    def test_cache_data(self):
-        cd = CacheData('sec', 'key', 'value', 0)
-        self.assertEqual(repr(cd), "CacheData('sec','key','value',0)")
-
     def test_repr(self):
         cd = CacheData('sec', 'key', 'value', 0)
         cdf = CacheDataFile('test', cd)
         self.assertEqual(
-            repr(cdf), "CacheDataFile('test',CacheData('sec','key','value',0))")
+            repr(cdf),
+            "CacheDataFile('test',CacheData('sec','key','value',0))")
 
     @patch("os.path.isfile", Mock())
     def test_load_exception(self):
@@ -46,7 +40,7 @@ class TestCacheDataFile(unittest.TestCase):
         cdf = CacheDataFile()
         self.assertFalse(cdf.load('abcd'))
 
-    @patch("json.dumps", lambda *args, **kwargs: raise_test_exception())
+    @patch("json.dumps", force_exception)
     def test_save_exception(self):
         cd = CacheData("sec", "key", "value", 0)
         cdf = CacheDataFile(cache_data=cd)
